Input<T> mixin
- Implemented types
-
- StreamSink<
T>
- StreamSink<
- Mixin applications
- Available extensions
Properties
-
done
→ Future<
void> -
Return a future which is completed when the StreamSink is finished.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputStream
→ StreamController<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
T event) → void -
Adds a data
eventto the sink.override -
addError(
Object error, [StackTrace? stackTrace]) → void -
Adds an
errorto the sink.override -
addStream(
Stream< T> stream) → Future<void> -
Consumes the elements of
stream.override -
close(
) → Future< void> -
Tells the stream sink that no further streams will be added.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rejectErrors(
) → StreamSink< T> -
Available on StreamSink<
Returns a StreamSink that forwards toT> , provided by the StreamSinkExtensions extensionthisbut rejects errors. -
toString(
) → String -
A string representation of this object.
inherited
-
transform<
S> (StreamSinkTransformer< S, T> transformer) → StreamSink<S> -
Available on StreamSink<
Transforms a StreamSink usingT> , provided by the StreamSinkExtensions extensiontransformer.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited